Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(508)

Unified Diff: components/sync/engine/engine_components_factory_impl.h

Issue 2413313004: [Sync] Move the last things out of core/. (Closed)
Patch Set: Address comments. Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/sync/engine/engine_components_factory_impl.h
diff --git a/components/sync/core/internal_components_factory_impl.h b/components/sync/engine/engine_components_factory_impl.h
similarity index 67%
rename from components/sync/core/internal_components_factory_impl.h
rename to components/sync/engine/engine_components_factory_impl.h
index 9836220b5c5f215ce4b0868a88cc62f025315bee..476bdf11a66b717d84e198b81c1f3d2f9b257ab5 100644
--- a/components/sync/core/internal_components_factory_impl.h
+++ b/components/sync/engine/engine_components_factory_impl.h
@@ -2,25 +2,25 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
//
// An InternalComponentsFactory implementation designed for real production /
// normal use.
-#ifndef COMPONENTS_SYNC_CORE_INTERNAL_COMPONENTS_FACTORY_IMPL_H_
-#define COMPONENTS_SYNC_CORE_INTERNAL_COMPONENTS_FACTORY_IMPL_H_
+#ifndef COMPONENTS_SYNC_ENGINE_ENGINE_COMPONENTS_FACTORY_IMPL_H_
+#define COMPONENTS_SYNC_ENGINE_ENGINE_COMPONENTS_FACTORY_IMPL_H_
#include <memory>
#include <string>
#include <vector>
#include "base/macros.h"
-#include "components/sync/core/internal_components_factory.h"
+#include "components/sync/engine/engine_components_factory.h"
namespace syncer {
-class InternalComponentsFactoryImpl : public InternalComponentsFactory {
+class EngineComponentsFactoryImpl : public EngineComponentsFactory {
public:
- explicit InternalComponentsFactoryImpl(const Switches& switches);
- ~InternalComponentsFactoryImpl() override;
+ explicit EngineComponentsFactoryImpl(const Switches& switches);
+ ~EngineComponentsFactoryImpl() override;
std::unique_ptr<SyncScheduler> BuildScheduler(
const std::string& name,
@@ -45,9 +45,9 @@ class InternalComponentsFactoryImpl : public InternalComponentsFactory {
private:
const Switches switches_;
- DISALLOW_COPY_AND_ASSIGN(InternalComponentsFactoryImpl);
+ DISALLOW_COPY_AND_ASSIGN(EngineComponentsFactoryImpl);
};
} // namespace syncer
-#endif // COMPONENTS_SYNC_CORE_INTERNAL_COMPONENTS_FACTORY_IMPL_H_
+#endif // COMPONENTS_SYNC_ENGINE_ENGINE_COMPONENTS_FACTORY_IMPL_H_
« no previous file with comments | « components/sync/engine/engine_components_factory.h ('k') | components/sync/engine/engine_components_factory_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -2,25 +2,25 @@
// found in the LICENSE file.
//
-// An InternalComponentsFactory implementation designed for real production /
+// An EngineComponentsFactory implementation designed for real production /
// normal use.
This is Rietveld 408576698